@@ -1,7 +1,8 @@
 #! /bin/sh
 
-## Checks gcg blast output
+## Verbose mode
+test "x$VERBOSE" = xx && set -x
 
+## Checks gcg blast output
 ../html4blast -g -o gcg.html ${srcdir}/gcg.blast
 
-
