@@ -1,6 +1,8 @@
 #! /bin/sh
 
-## Checks ncbi very very large blast output
+## Verbose mode
+test "x$VERBOSE" = xx && set -x
 
+## Checks ncbi very very large blast output
 ../html4blast -g -o trunc.html ${srcdir}/trunc.blast
 
